# _*_ coding: utf8 _*_
import time # В этом модуле - задержки
import smbus # В этом модуле - средства для работы с шиной i2c

""" Консольное приложение для тестирования цифрового модуля
    
    Приложение получает по i2c с цифрового модуля буфер данных, представляющих
    собой 8 двухбайтовых слов, по одному на канал цифрового модуля.
    Интерпретация этих слов зависит от устройств (датчиков), которые подключены
    к каналам цифрового модуля. На данный момент предусмотрены три типа
    датчиков:
    1. Температурные датчики DS18B20. Для того, чтобы получить температуру в 
       градусах Цельсия, необходимо код, получаенный от соответствующего канала
       цифрового модуля умножить на 0.0626.
    2. Релейные датчики (концевики, термоконтакты и т.п.). Если контакт
      замкнут - цифровой модуль возвращает с соотвествующего канала 0, а если
      разомкнут - 65535 (т.е. все биты двухбайтового слова - единички)
    3. Аналоговые датчики (аналоговые датчики температуры, датчики давления
       и т.п.), подключенные к АЦП с 1-Wire интерфейсом, выполненными на
       микроконтроллере ATtiny85. В этом случае цифровой модуль с соответствую-
       щего канала выдает непосредственно код АЦП. 
 """

bus = smbus.SMBus(1) # Создаем объект "шина"
addrDM = 0x15 # Адрес цифрового модуля

buf = [0]*16  # Буфер для приема байтов от цифрового модуля
cntr = 0      # Счетчик успешный измерений
colls = 0     # Счетчик коллизий

while True: # Бесконечный цикл
  tries = 100 # Максимальное количество попыток доступа к данным модуля
  while tries > 0: 
    try: # Попытаемся получить данные
      bus.write_byte(addrDM, 0x00) # Сбрасываем индекс байтов в буфере модуля
      for i in range(16): # Считываем последовательно 16 байтов буфера
        buf[i] = bus.read_byte(addrDM)
      break
    except IOError:   # Устройство еще не готово - подождем 0.1 сек
      time.sleep(0.1) # и опять попробуем
      tries -= 1
      colls += 1      # Модифицируем счетчик коллизий
  if tries <= 0: # Что-то серьезно не так...
    print 'Цифровой модуль не доступен по i2c. Завершение работы.'
    sys.exit(1)
    
  cntr += 1 # Успешное чтение всех данных; модифицируем счетчик
  print cntr,
  for i in range(8):
    w = buf[2*i]*256 + buf[2*i + 1] # Формируем слова из соседних пар байтов
    if i < 4: # Данные с DS18B20 - подсветим зелененьким
      print '\x1b[32m',
    elif i == 6: # Данные с АЦП - подсветим фиолетовым
      print '\x1b[35m',
    print w,
    print '\x1b[0m',
  print 'err = %d' % (colls)
  time.sleep(1) # Секундная пауза
